<p align="center">
  <a href="https://github.com/Mukhopadhyay/pyfake"><img src="https://raw.githubusercontent.com/Mukhopadhyay/pyfake/refs/heads/master/docs/assets/logo.png" alt="Pyfake" ></a>
</p>

<p align="center">
<i>A Flexible and Extensible fake data generator based on <strong>Pydantic</strong> models.</i>
</p>

<p align="center">
<a href="https://pypi.org/project/pyfake/" target="_blank">
<img src="https://img.shields.io/pypi/v/pyfake?pypiBaseUrl=https%3A%2F%2Fpypi.org&style=for-the-badge"/></a> <img src="https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54"/> <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/pydantic/pydantic/main/docs/badge/v2.json&style=for-the-badge"/>
</p>
